/* includes for compiling .cmm files via-C */
#include "Stg.h"
#include "Rts.h"
#include "RtsFlags.h"
#include "RtsUtils.h"
#include "StgRun.h"
#include "Storage.h"
#include "Schedule.h"
#include "Printer.h"
#include "Sanity.h"
#include "STM.h"
#include "SchedAPI.h"
#include "Timer.h"
#include "ProfHeap.h"
#include "LdvProfile.h"
#include "Profiling.h"
#include "OSThreads.h"
#include "Apply.h"
#include "SMP.h"
#include "RaiseAsync.h"
#include "ThreadLabels.h"
#include "Threads.h"
#include "Prelude.h"
#include "Stable.h"
